==> classpath-0.11-rc1.tar.gz: classpath-0.11-rc1/native/jni/java-nio/java_nio_DirectByteBufferImpl.c <==
/* java_nio_DirectByteBufferImpl.c - Native methods for DirectByteBufferImpl
   Copyright (C) 2003, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

#include <config.h>
#include <errno.h>

#include <jni.h>
#include <jcl.h>

#include "java_nio_DirectByteBufferImpl.h"

#define IO_EXCEPTION "java/io/IOException"

JNIEXPORT jobject JNICALL
Java_java_nio_DirectByteBufferImpl_allocateImpl (JNIEnv *env, jclass class, jint size)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.allocateImpl(): not implemented");
  return 0;
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_freeImpl (JNIEnv *env, jclass class, jobject address)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.freeImpl(): not implemented");
}

JNIEXPORT jbyte JNICALL
Java_java_nio_DirectByteBufferImpl_getImpl__Lgnu_classpath_RawData_2I
  (JNIEnv *env, jclass clazz, jobject address, jint index)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.getImpl(): not implemented");
  return 0;
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_putImpl (JNIEnv *env, jclass class, jobject address, jint index, jbyte value)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.putImpl(): not implemented");
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_getImpl__Lgnu_classpath_RawData_2I_3BII
  (JNIEnv *env, jclass clazz, jobject address, jint index, jbyteArray dst_buffer, jint dst_offset, jint dst_len)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.getImpl(): not implemented");
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_shiftDown (JNIEnv *env, jclass clazz, jobject address, jint dst_offset, jint src_offset, jint count)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.shiftDown(): not implemented");
}

JNIEXPORT jobject JNICALL
Java_java_nio_DirectByteBufferImpl_adjustAddress (JNIEnv *env, jclass class, jobject address, jint offset)
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.adjustAddress(): not implemented");
  return NULL;
}

==> classpath_0.12.orig.tar.gz: classpath-0.12/native/jni/java-nio/java_nio_DirectByteBufferImpl.c <==
/* java_nio_DirectByteBufferImpl.c - Native methods for DirectByteBufferImpl
   Copyright (C) 2003, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

#include <config.h>
#include <errno.h>

#include <jni.h>
#include <jcl.h>

#include "java_nio_DirectByteBufferImpl.h"

#define IO_EXCEPTION "java/io/IOException"

JNIEXPORT jobject JNICALL
Java_java_nio_DirectByteBufferImpl_allocateImpl (JNIEnv *env, 
						 jclass class
						 __attribute__ ((__unused__)),
						 jint size
						 __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.allocateImpl(): not implemented");
  return 0;
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_freeImpl (JNIEnv *env,
					     jclass class
					     __attribute__ ((__unused__)),
					     jobject address
					     __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.freeImpl(): not implemented");
}

JNIEXPORT jbyte JNICALL
Java_java_nio_DirectByteBufferImpl_getImpl__Lgnu_classpath_RawData_2I
  (JNIEnv *env,
   jclass clazz __attribute__ ((__unused__)),
   jobject address __attribute__ ((__unused__)),
   jint index __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.getImpl(): not implemented");
  return 0;
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_putImpl (JNIEnv *env,
					    jclass class
					    __attribute__ ((__unused__)),
					    jobject address
					    __attribute__ ((__unused__)),
					    jint index
					    __attribute__ ((__unused__)),
					    jbyte value
					    __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.putImpl(): not implemented");
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_getImpl__Lgnu_classpath_RawData_2I_3BII
  (JNIEnv *env,
   jclass clazz __attribute__ ((__unused__)),
   jobject address __attribute__ ((__unused__)),
   jint index __attribute__ ((__unused__)),
   jbyteArray dst_buffer __attribute__ ((__unused__)),
   jint dst_offset __attribute__ ((__unused__)),
   jint dst_len __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.getImpl(): not implemented");
}

JNIEXPORT void JNICALL
Java_java_nio_DirectByteBufferImpl_shiftDown
  (JNIEnv *env,
   jclass clazz __attribute__ ((__unused__)),
   jobject address __attribute__ ((__unused__)),
   jint dst_offset __attribute__ ((__unused__)),
   jint src_offset __attribute__ ((__unused__)),
   jint count __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.shiftDown(): not implemented");
}

JNIEXPORT jobject JNICALL
Java_java_nio_DirectByteBufferImpl_adjustAddress
  (JNIEnv *env,
   jclass class __attribute__ ((__unused__)),
   jobject address __attribute__ ((__unused__)),
   jint offset __attribute__ ((__unused__)))
{
  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.DirectByteBufferImpl.adjustAddress(): not implemented");
  return NULL;
}
